@@ -487,7 +487,7 @@ def get_consommation_sum(customer):
         "WHERE customer ilike '%{customer}%' "
         "AND datetime >= '{date}'::date "  # YYYY-MM-DD
         "AND source='internet' "
-        "AND (extract('ISODOW' FROM datetime) between 1 AND 5 "
+        "AND ((extract('ISODOW' FROM datetime) between 1 AND 5) "
         "AND extract(HOUR FROM datetime) < 19 "
         "AND extract(HOUR FROM datetime) > 8 "
         "GROUP BY customer;"
